@@ -27,7 +27,7 @@ class SE2(jdc.EnforcedAnnotationsMixin, _base.SEBase[SO2]):
 
     unit_complex_xy: Annotated[
         jnp.ndarray,
-        (4,),  # Shape.
+        (..., 4),  # Shape.
         jnp.floating,  # Data-type.
     ]
     """Internal parameters. `(cos, sin, x, y)`."""
@@ -126,7 +126,7 @@ class SE2(jdc.EnforcedAnnotationsMixin, _base.SEBase[SO2]):
             theta,
         )
 
-        theta_sq = theta ** 2
+        theta_sq = theta**2
         sin_over_theta = jnp.where(
             use_taylor,
             1.0 - theta_sq / 6.0,
@@ -150,7 +150,7 @@ class SE2(jdc.EnforcedAnnotationsMixin, _base.SEBase[SO2]):
         )
 
     @overrides
-    def log(self: "SE2") -> jnp.ndarray:
+    def log(self) -> jnp.ndarray:
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/se2.hpp#L160
         # Also see:
@@ -174,7 +174,7 @@ class SE2(jdc.EnforcedAnnotationsMixin, _base.SEBase[SO2]):
         half_theta_over_tan_half_theta = jnp.where(
             use_taylor,
             # Taylor approximation.
-            1.0 - (theta ** 2) / 12.0,
+            1.0 - theta**2 / 12.0,
             # Default.
             -(half_theta * jnp.sin(theta)) / safe_cos_minus_one,
         )
